<?php
/**
 * Simple Picasa user photos feed widget
 *
 * @author Julien GUILLE
 */
if (!defined('DC_RC_PATH')) { return; }

require dirname(__FILE__).'/_widgets.php';

class publicPicasaFeedWidget
{
  
  /**
   * Picasa user photos rss2 feed url pattern
   * @const string
   */
  const PICASA_USER_FEED_URL = 'http://picasaweb.google.com/data/feed/base/user/%s%s?kind=photo&alt=rss&max-results=10&access=public&hl=fr';

  /**
   * Main widget output generation method
   *
   * @param  Widget  $w
   */
	public static function picasaFeedWidget(&$w)
	{
		if (!$w->picasa_id)
		{
		  echo __('You must provide a valid Picasa / Google user id.');
		  return;
		}
		
		if (!$w->nb_photos)
		{
		  $w->nb_photos = 6;
		}
		if (!$w->size)
		{
		  $w->size = '/s144';
		}

		$album_url = '';
		if ($w->album_id)
		{
		  $album_url = '/album/' . $w->album_id;
		}
		$feed_url = sprintf(self::PICASA_USER_FEED_URL, $w->picasa_id, $album_url);
		
		try 
		{
		  $feed = feedReader::quickParse($feed_url, DC_TPL_CACHE);
		  if ($feed == false || count($feed->items) == 0) 
		  {
			return;
		  }   
		} 
		catch (Exception $e) 
		{
		  return;
		}   

		echo '<div class="picasafeed">'.
			($w->title ? '<h2>'.html::escapeHTML($w->title).'</h2>' : '')."\n";
		
		if ($w->shuffle)
		{
		  shuffle($feed->items);
		}

		$i = 0;	
		foreach ($feed->items as $item) 
		{
		  $description = html_entity_decode($item->description);
		  $matches = array();
		  $itemtitle = html::escapeHtml($item->title);
		  
		  if (preg_match_all('/src="(.*?)"/', $description, $matches))
		  {
			$thumb = str_replace('/s288', $w->size, $matches[1][0]);
			$content = sprintf('<img src="%s" alt="%s" />',
							   $thumb, $itemtitle);
		  }
		  else
		  {
			$content = $itemtitle;
		  }

		  echo '<a href="'.$item->link.'" onclick="this.target=\'_blank\';">'.$content.'</a>'."\n";
		  $i++;
		  if ($i >= $w->nb_photos) 
		  {
			break;
		  }   
		}
		
		echo sprintf('<p><a href="%s">%s</a></p>', $feed->link, $feed->title);
		echo '</div>';

		return;
	}
}
?>